/* eslint-disable import/no-extraneous-dependencies,no-console,no-shadow */
const path = require('path');
const chalk = require('chalk');
const webpack = require('webpack');
const merge = require('webpack-merge');
const { handleCompilationError, lambdaServerHandlers, checkAssetManifest } = require('./utils');
const { client, server } = require('./webpack.common');
const paths = require('./paths');
const OptimizeCSSAssetsPlugin = require('optimize-css-assets-webpack-plugin');

module.exports = () => {
  checkAssetManifest();
  const serverConfig = merge(server, {
    entry: {
      server: path.resolve(paths.src, 'server', 'lambda.js'),
      ...lambdaServerHandlers(path.resolve(paths.src, 'api')),
      ...lambdaServerHandlers(path.resolve(paths.src, 'batches')),
      ...lambdaServerHandlers(path.resolve(paths.src, 'streams'))
    },
    mode: 'production'
  });

  const clientConfig = merge(client, {
    mode: 'production',
    optimization: {
      minimizer: [
        new OptimizeCSSAssetsPlugin({
          cssProcessorPluginOptions: {
            preset: ['default', { discardComments: { removeAll: true } }],
          }
        })
      ]
    }
  });

  console.log(`Starting build for environment: ${process.env.ENV || 'local'}`);

  webpack(clientConfig, (err, stats) => {
    handleCompilationError(err, stats);
    console.log(chalk.green('Client build succeeded'));

    webpack(serverConfig, (err, stats) => {
      handleCompilationError(err, stats);
      console.log(chalk.green('Server build succeeded'));
    });
  });
};
