#!/usr/bin/env node
const program = require('commander');
const cliPkg = require('../package.json');
const start = require('./start');
const build = require('./build');
const buildCommons = require('./buildCommons');
const deployAssets = require('./deploy-assets');
const deployStaticAssets = require('./deploy-static-assets');
const clean = require('./clean');

console.log(`cbm-fragment-script version: ${cliPkg.version}`);

program.version(cliPkg.version).description(cliPkg.description);
program
  .command('start')
  .alias('s')
  .description('start a local fragment server')
  .action(() => {
    start();
  });
program
  .command('build')
  .alias('b')
  .description('build a fragment server')
  .action(() => {
    build();
  });
program
  .command('build-commons <entrypoint>')
  .alias('bc')
  .description('build commons library')
  .action(entrypoint => {
    buildCommons(entrypoint);
  });

program
  .command('deploy-assets')
  .alias('da')
  .description('deploy assets to S3')
  .option('--delete', 'deletes the files that exist in the destination but not in the source.')
  .action(() => {
    deployAssets();
  });

program
  .command('deploy-static-assets')
  .alias('dsa')
  .description('deploy static assets to S3')
  .action(() => {
    deployStaticAssets();
  });

program
  .command('clean')
  .alias('c')
  .description('clean build folder')
  .action(() => {
    clean();
  });

program.parse(process.argv);
