const _ = require('lodash');
const chalk = require('chalk');
const paths = require('./paths');
const targetPkg = require(paths.pkg);

// Check configuration in package.json
const { buildConf } = targetPkg;

if (!buildConf) {
  console.error(chalk.red('buildConf key is not set in the package.json'));
  process.exit(1);
}
const mandatoryKey = ['bucketPrefix', 'bucketDir', 'assetsHosts', 'devPort'];
const missingConfiguration = (conf, keys) => {
  return keys.filter(key => !_.has(conf, key));
};

const missingKeys = missingConfiguration(buildConf, mandatoryKey);

if (!process.env.ENV) {
  console.error(chalk.red(`ENV is not set`));
  console.error(chalk.red(`You should set ENV to local to run this locally 'ENV=local npm run start'`));
  process.exit(1);
}

if (missingKeys.length !== 0) {
  missingKeys.forEach(missignKey => {
    console.error(
      chalk.red(`buildConf missing on of the following mandatory parameters: ${missignKey}`)
    );
  });
  process.exit(1);
}

let externals = {
  'cbm-auth': 'cbm-auth',
  jquery: 'jquery',
  'raven-js': 'raven-js',
  react: 'react',
  'react-dom': 'react-dom',
};

if (buildConf.externals) {
  externals = Object.assign({}, buildConf.externals, externals);
}

const { bucketPrefix, bucketDir, devPort, maxAge = 86400, assetsHosts } = buildConf;

const bucket = `${bucketPrefix}.${process.env.ENV}`;

let assetsHost = buildConf.assetsHosts[process.env.ENV];
let symlinksLibrary = true;
if (process.env.ENV === 'local') {
  symlinksLibrary = false;
}
const assetsBaseUrl = `${assetsHost}/static/fragment-${bucketDir}`;

const configuration = {
  assetsBaseUrl,
  bucketDir,
  bucket,
  devPort,
  maxAge,
  externals,
  symlinksLibrary,
};

console.log(
  chalk.green(
    `Fragments build with the following configuration ${JSON.stringify(configuration, null, 2)}`
  )
);
module.exports = configuration;
