/* eslint-disable import/no-extraneous-dependencies */
const { exec, find, cd, set } = require('shelljs');
const { bucket, bucketDir, maxAge } = require('./conf');
const paths = require('./paths');

const maxAgeHeader = maxAge ? `--cache-control="max-age=${maxAge}"` : '';
let cmd = [
  `aws s3 sync . s3://${bucket}/fragments/${bucketDir} ${maxAgeHeader}`,
];

if (process.argv.includes('--delete')) {
  cmd.push('--delete');
}

module.exports = () => {
  set('-e');

  // Copy build/static/ to the assets bucket
  cd(paths.assets);
  exec(cmd.join(' '));

  // We need to send the svg files separately adding with the correct content-type
  // because the s3 sync command will treat them as binary/octet-stream
  find('.')
    .filter(file => file.match(/\.svg/))
    .forEach(file => {
      const s3Url = `s3://${bucket}/fragments/${bucketDir}/${file}`;
      const opts = "--acl public-read --content-type 'image/svg+xml'";

      exec(`aws s3 cp ${file} ${s3Url} ${opts} `);
    });
};
