/* eslint-disable no-console,import/no-extraneous-dependencies */
const path = require('path');
const webpack = require('webpack');
const nodemon = require('nodemon');
const merge = require('webpack-merge');
const chalk = require('chalk');
const { client, server } = require('./webpack.common');
const paths = require('./paths');
const { handleCompilationError, lambdaServerHandlers, checkAssetManifest } = require('./utils');
const { devPort } = require('./conf');

module.exports = () => {
  checkAssetManifest();
  const webpackBuildConfigs = [];

  webpackBuildConfigs.push(
    merge(server, {
      entry: {
        server: path.resolve(paths.src, 'server', 'app.local.js'),
        ...lambdaServerHandlers(path.resolve(paths.src, 'api')),
        ...lambdaServerHandlers(path.resolve(paths.src, 'batches')),
        ...lambdaServerHandlers(path.resolve(paths.src, 'streams'))
      },
      mode: 'development',
      devtool: 'inline-source-map'
    })
  );

  // If at least one client entry is found,
  // then we add client build config
  if (Object.keys(client.entry).length > 0) {
    webpackBuildConfigs.push(
      merge(client, {
        mode: 'development',
        devtool: 'inline-source-map'
      })
    );
  }

  const compiler = webpack(webpackBuildConfigs);

  let isServerRunning = false;

  compiler.watch(
    {
      aggregateTimeout: 300,
      poll: undefined
    },
    (err, stats) => {
      handleCompilationError(err, stats);
      console.log(chalk.green('build succeeded'));

      // We dont want to start the server again on subsequent compilations
      // that will be triggered by watch
      if (!isServerRunning) {
        const serverPath = `${paths.build}/server.js`;

        // Set watch option so that nodemon doesn't watch the whole directory
        // (otherwise it would restart twice when the client changes)
        nodemon({
          script: serverPath,
          watch: serverPath,
          env: {
            PORT: devPort
          }
        });
        isServerRunning = true;

        // Make sure nodemon is killed when the script is stopped
        ['SIGINT', 'SIGTERM'].forEach(sig => {
          process.on(sig, () => {
            nodemon.emit('quit');
            process.exit();
          });
        });
      }
    }
  );
};
